import { UserManager, UserManagerSettings, SigninRedirectArgs, SignoutRedirectArgs } from "oidc-client-ts";
import { User as OidcClientUser } from "oidc-client-ts";
import { User as User$0 } from "oidc-client-ts";
import { ApolloClient, TypedDocumentNode, OperationVariables, QueryOptions, NormalizedCacheObject, ApolloQueryResult, ApolloError, DocumentNode, InMemoryCache, ApolloClientOptions } from "@apollo/client";
type Profile = OidcClientUser["profile"];
type SignalType = string;
type SignalNamespace = string;
type SignalPayload = Record<string, unknown> | Error;
interface ConnectedModule {
    connect: (beacon: Beacon) => void;
    namespace: SignalNamespace;
}
type SignalContext = ConnectedModule;
type Signal<P = SignalType, T extends SignalPayload = SignalPayload> = {
    type?: P;
    namespace?: SignalType;
    payload?: T;
    context?: ConnectedModule;
};
type SignalListener = (signal: Signal) => void;
type SignalTriggerProps = Omit<Signal, "context"> & {
    context?: Record<string, string>;
};
type SignalTrigger = (signal: Signal) => boolean;
type SignalListenerSource = SignalType | Signal | SignalTrigger | SignalTriggerProps;
type Disposer = () => void;
type Beacon = {
    emit: (signal: Signal) => void;
    addListener: (triggerOrSignalProps: SignalListenerSource, listener: SignalListener) => Disposer;
    addSignalContext: (context: ConnectedModule) => Disposer;
    getSignalContext: (namespace: SignalNamespace) => ConnectedModule | undefined;
    getAllSignalContextsAsObject: () => Record<string, ConnectedModule>;
    clear: () => void;
};
declare function createSignalTrigger(signalOrJustSignalType: SignalType | Signal | SignalTriggerProps): SignalTrigger;
declare function createBeacon(): Beacon;
type TokenData = Record<string, string>;
interface ApiTokenClient extends ConnectedModule {
    fetch: (user: User$0) => Promise<TokenData>;
    getTokens: () => TokenData | null;
    clear: () => void;
    isRenewing: () => boolean;
}
type ApiTokenClientProps = {
    url: string;
    maxRetries?: number;
    retryInterval?: number;
    queryProps?: {
        permission: string;
        grantType: string;
    };
    audiences?: string[];
};
type ApiTokensClientEvent = keyof typeof apiTokensClientEvents;
declare const apiTokensClientNamespace = "apiTokensClient";
declare const apiTokensClientEvents: {
    readonly API_TOKENS_UPDATED: "API_TOKENS_UPDATED";
    readonly API_TOKENS_RENEWAL_STARTED: "API_TOKENS_RENEWAL_STARTED";
    readonly API_TOKENS_REMOVED: "API_TOKENS_REMOVED";
};
interface SessionPoller extends ConnectedModule {
    start: () => void;
    stop: () => void;
}
type SessionPollerOptions = {
    pollIntervalInMs: number;
};
type SessionPollerEvent = keyof typeof sessionPollerEvents;
declare const sessionPollerNamespace = "sessionPoller";
declare const sessionPollerEvents: {
    readonly SESSION_POLLING_STARTED: "SESSION_POLLING_STARTED";
    readonly SESSION_POLLING_STOPPED: "SESSION_POLLING_STOPPED";
};
declare function createSessionPoller(options?: SessionPollerOptions): SessionPoller;
type GraphQLModuleErrorType = keyof typeof graphQLModuleError;
declare const graphQLModuleError: {
    readonly GRAPHQL_LOAD_FAILED: "GRAPHQL_LOAD_FAILED";
    readonly GRAPHQL_NO_CLIENT: "GRAPHQL_NO_CLIENT";
    readonly GRAPHQL_NO_API_TOKENS: "GRAPHQL_NO_API_TOKENS";
};
declare class GraphQLModuleError extends Error {
    message: string;
    type: GraphQLModuleErrorType;
    originalError?: Error | null;
    constructor(message: string, type: GraphQLModuleErrorType, originalError?: Error | null);
    get isLoadError(): boolean;
    get isNoClientError(): boolean;
    get isNoApiTokensError(): boolean;
}
type GraphQLQueryResult = {
    [key: string]: unknown;
};
type GraphQLCache = NormalizedCacheObject;
type GraphQLModule<T = NormalizedCacheObject, Q = GraphQLQueryResult> = ConnectedModule & {
    /**
     * Cancels current query. The pending query is aborted.
     */
    cancel: () => void;
    /**
     * Calls cancel() and also clears errors and results. Emits a GRAPHQL_MODULE_CLEARED event.
     */
    clear: () => void;
    /**
     * Returns array of query errors and/or errors in the result data.
     */
    getClientErrors: () => ApolloError[];
    /**
     * Returns the data property of last successful query result.
     */
    getData: () => Q | undefined;
    /**
     * Returns a query error.
     */
    getError: () => GraphQLModuleError | undefined;
    /**
     * Returns the current pending query promise or an immediately rejected promise.
     */
    getQueryPromise: () => Promise<ApolloQueryResult<Q>>;
    /**
     * Returns the latest query result.
     */
    getResult: () => ApolloQueryResult<Q> | undefined;
    /**
     * Returns true if a query fetch is currently active.
     */
    isLoading: () => boolean;
    /**
     * Returns true if the module is waiting for api tokens or query results.
     */
    isPending: () => boolean;
    /**
     * Executes a query.
     */
    query: (props?: Partial<GraphQLModuleModuleProps<T, Q>>) => Promise<ApolloQueryResult<Q>>;
    /**
     * Calls query(options) with fetchPolicy: 'cache-only' in options.
     */
    queryCache: (props?: Partial<GraphQLModuleModuleProps<T, Q>>) => Promise<ApolloQueryResult<Q>>;
    /**
     * Calls query(options) with fetchPolicy: 'network-only' in options.
     */
    queryServer: (props?: Partial<GraphQLModuleModuleProps<T, Q>>) => Promise<ApolloQueryResult<Q>>;
    /**
     * Sets the graphQLClient.
     */
    setClient: (client: ApolloClient<T>) => void;
    /**
     * Returns a promise that is resolved when api tokens are found.
     */
    waitForApiTokens: () => Promise<boolean>;
};
type GraphQLModuleModuleProps<T = NormalizedCacheObject, Q = GraphQLQueryResult> = {
    /**
     * Optional property, but must be set before the query is executed.
     */
    graphQLClient?: ApolloClient<T>;
    /**
     * Get the client from modules.
     */
    useApolloClientModule?: boolean;
    /**
     * GraphQL module options.
     */
    options?: Partial<{
        /**
         * Should query be executed automatically on initialization. Default true.
         */
        autoFetch: boolean;
        /**
         * Are api tokens required for queries. Default true.
         */
        requireApiTokens: boolean;
        /**
         * Should an on-going query be aborted when querying again. Default true.
         */
        abortIfLoading: boolean;
        /**
         * Should old result be kept, if a newer query fails. Default false.
         */
        keepOldResultOnError: boolean;
        /**
         * How long in milliseconds should api tokens be awaited before rejecting a query. Default 15 000.
         */
        apiTokensWaitTime: number;
        /**
         * An object key for the api token to use in a query.
         */
        apiTokenKey?: string;
    }>;
    /**
     * A graphQL query document.
     */
    query?: TypedDocumentNode<Q, OperationVariables> | DocumentNode;
    /**
     * This function is called before a query is executed. The options object returned by the function is used as query options.
     */
    queryHelper?: (currentOptions: QueryOptions<OperationVariables, Q>, apiTokenClient: ApiTokenClient | undefined, beacon: Beacon | undefined) => QueryOptions<OperationVariables, Q>;
    /**
     * Other ApolloClient queryOptions except query document.
     */
    queryOptions?: Omit<QueryOptions<OperationVariables, Q>, "query">;
};
declare const graphQLModuleNamespace = "graphQLModule";
type GraphQLModuleEvent = keyof typeof graphQLModuleEvents;
declare const graphQLModuleEvents: {
    readonly GRAPHQL_MODULE_LOADING: "GRAPHQL_MODULE_LOADING";
    readonly GRAPHQL_MODULE_LOAD_SUCCESS: "GRAPHQL_MODULE_LOAD_SUCCESS";
    readonly GRAPHQL_MODULE_LOAD_ABORTED: "GRAPHQL_MODULE_LOAD_ABORTED";
    readonly GRAPHQL_MODULE_CLEARED: "GRAPHQL_MODULE_CLEARED";
};
type ApiTokenClientTrackerProps = {
    /**
     * How long to wait for apitoken renewal to fulfill. Default 15000ms.
     */
    timeout?: number;
    /**
     * If true, the stored api tokens are not cleared when renewal starts. Default true.
     */
    keepTokensWhileRenewing?: boolean;
    /**
     * If renewal fails, should old tokens be kept of not.
     */
    keepTokensAfterRenewalError?: boolean;
    /**
     * Type of the signal that should end the pending api token renewal promise.
     * Usually it is a clear/dispose signal from the module using this util, so the promise is fulfilled when the module is not used anymore.
     */
    rejectionSignalTrigger?: SignalTriggerProps;
    /**
     * Called when api tokens change. Not called when dispose() is called.
     */
    onChange?: (tokens: TokenData, changeTrigger: Signal) => void;
};
type ApiTokenClientTracker = {
    /**
     * Connect the utility to a beacon
     */
    connect: (connectedBeacon: Beacon) => void;
    /**
     * Get current tokens
     */
    getTokens: () => TokenData;
    /**
     * Dispose listeners, references and data
     */
    dispose: Disposer;
    /**
     * Discards pending promise for api token renewal.
     * Emits signal to abort it. Same signal is used in all instance of this utility, so the signal stops them all.
     */
    stopWaitingForTokens: Disposer;
    /**
     * Returns the pending renewal promise or immediately resolved promise.
     * Never rejects, the returned boolean indicates was the promise successful.
     */
    waitForApiTokens: () => Promise<boolean>;
    /**
     * Returns true, if renewal process is on-going
     */
    isRenewing: () => boolean;
};
/**
 * Utility for tracking changes in the apiTokenClient module
 * Use it in the connect() function of any ConnectedModule.
 */
declare function createApiTokenClientTracker({ timeout, keepTokensWhileRenewing, keepTokensAfterRenewalError, rejectionSignalTrigger, onChange }: ApiTokenClientTrackerProps): ApiTokenClientTracker;
type TokenSetter = (headers: Record<string, string>, tokens: TokenData) => Record<string, string>;
type ApolloClientModule<T = InMemoryCache> = ConnectedModule & {
    /**
     * Returns the client.
     */
    getClient: () => ApolloClient<T>;
    /**
     * Returns the apiTokenClient tracker.
     */
    getTracker: () => ApiTokenClientTracker;
    /**
     * Resets the client and apiTokenTracker.
     */
    reset: () => Promise<void>;
};
type ApolloClientModuleProps<T = InMemoryCache> = {
    /**
     * How long in milliseconds should api tokens be awaited before rejecting a query.
     * Default 15 000, set in createApiTokenClientTracker.
     */
    apiTokensWaitTime?: number;
    /**
     * Function to return tokens appended to the headers
     * @param headers Current headers in the request
     * @param tokens All tokens from the apiTokenClient
     */
    tokenSetter?: TokenSetter;
    /**
     * Options for the ApolloClient. If "uri" option is given, a HttpLink is automatically created from it.
     * The module adds its own AplloLink(s) before other links.
     * Default cache is InMemoryCache.
     */
    clientOptions: Partial<ApolloClientOptions<T>>;
    /**
     * If true, the stored api tokens are not cleared when renewal starts.
     * Default true, set in createApiTokenClientTracker.
     */
    keepTokensWhileRenewing?: boolean;
    /**
     * If true, a ApolloLink is added to wait for possible api token renewal to end.
     * If false, there might be times when queries are made with old api tokens. Unlikely, but possible.
     * Default true.
     */
    preventQueriesWhileRenewing?: boolean;
};
declare const apolloClientModuleEvents: {
    readonly APOLLO_CLIENT_MODULE_RESET: "APOLLO_CLIENT_MODULE_RESET";
};
type ApolloClientModuleEvent = keyof typeof apolloClientModuleEvents;
declare const apolloClientModuleNamespace = "apolloClient";
type OidcClientErrorType = keyof typeof oidcClientErrors;
declare const oidcClientErrors: {
    readonly INVALID_OR_EXPIRED_USER: "INVALID_OR_EXPIRED_USER";
    readonly SIGNIN_ERROR: "SIGNIN_ERROR";
    readonly RENEWAL_FAILED: "RENEWAL_FAILED";
};
declare class OidcClientError extends Error {
    message: string;
    type: OidcClientErrorType;
    originalError?: Error | null;
    constructor(message: string, type: OidcClientErrorType, originalError?: Error | null);
    get isInvalidUserError(): boolean;
    get isSignInError(): boolean;
    get isRenewalError(): boolean;
}
type LoginProps = {
    language?: string;
} & SigninRedirectArgs;
type LogoutProps = {
    language?: string;
} & SignoutRedirectArgs;
type OidcClientProps = {
    userManagerSettings: Partial<UserManagerSettings>;
    debug?: boolean;
};
type UserReturnType = User$0 | null;
type ErrorReturnType = OidcClientError | null;
type RenewalResult = [
    ErrorReturnType,
    UserReturnType
];
type OidcClientState = keyof typeof oidcClientStates;
type OidcClientEvent = keyof typeof oidcClientEvents;
// User['profile']['amr'] has type of "unknown"
type Amr = string[];
interface OidcClient extends ConnectedModule {
    /**
     *
     * Returns user's Amr values. Tunnistamo returns the amr as string, which oidc-client-ts rejects, because it violates the OIDC specification
     * Helsinki Profile returns proper value. This client has to support both.
     * If amr is not found from the user.profile, the user.id_token is decrypted and that amr is returned.
     * So cache the retured value instead of calling this function multiple times.
     */
    getAmr: () => Amr | undefined;
    /**
     * Returns current state
     */
    getState: () => OidcClientState;
    /**
     *
     * Returns a token. Function is async, because token renewal might be in progress and current token might be outdated after that.
     * If renewal was in progress, but failed, then old token is returned.
     * Use isRenewing() and exported function getUserToken(user, tokenType) to get token syncronously and safely.
     * The Promise will never reject.
     */
    getToken: (tokenType: "access" | "id" | "refresh") => Promise<string | undefined>;
    /**
     * Returns user object or null
     */
    getUser: () => UserReturnType;
    /**
     * Returns the client's UserManager
     */
    getUserManager: () => UserManager;
    /**
     * Handles the callback path and returns an user object - if user is valid
     */
    handleCallback: () => Promise<User$0>;
    /**
     *
     * Returns true, if user exists and user object passes isValidUser() check
     */
    isAuthenticated: () => boolean;
    /**
     *
     * Returns true if user renewal is in progress
     */
    isRenewing: () => boolean;
    /**
     * Calls the authorization_endpoint with given parameters
     * Browser window is redirected, the returned promise never fulfills
     */
    login: (props?: LoginProps) => Promise<void>;
    /**
     * Calls the end_session_endpoint with given parameters
     * Browser window is redirected, the returned promise never fulfills
     */
    logout: (props?: LogoutProps) => Promise<void>;
    /**
     *
     * For manual user renewal.
     * The Promise will never reject.
     */
    renewUser: () => Promise<RenewalResult>;
}
declare const oidcClientNamespace: SignalNamespace;
declare const oidcClientStates: {
    readonly NO_SESSION: "NO_SESSION";
    readonly VALID_SESSION: "VALID_SESSION";
    readonly LOGGING_IN: "LOGGING_IN";
    readonly LOGGING_OUT: "LOGGING_OUT";
    readonly HANDLING_LOGIN_CALLBACK: "HANDLING_LOGIN_CALLBACK";
};
declare const oidcClientEvents: {
    readonly USER_UPDATED: "USER_UPDATED";
    readonly USER_RENEWAL_STARTED: "USER_RENEWAL_STARTED";
    readonly USER_REMOVED: "USER_REMOVED";
};
type NamespacedBeacon = {
    storeBeacon: (target: Beacon) => void;
    emit: (signalType: SignalType, payload?: SignalPayload) => void;
    addListener: (signalOrJustType: SignalType | Signal, listener: ScopedSignalListener, excludeOwn?: boolean) => Disposer;
    emitError: (errorPayload?: ErrorPayload) => void;
    emitEvent: (eventType: EventType, data?: EventData) => void;
    emitStateChange: (state: StateChangeType, previousState?: StateChangeType) => void;
    namespace: SignalNamespace;
    getBeacon: () => Beacon | undefined;
};
type ScopedSignalListener = (signal: Signal, module: NamespacedBeacon, beacon: Beacon) => void;
declare const errorSignalType: "error";
type ErrorPayload = Error;
type ErrorSignal = Signal & {
    type: typeof errorSignalType;
    payload: ErrorPayload;
};
declare const eventSignalType: "event";
type EventType = unknown;
type EventData = unknown;
type EventPayload = {
    type: EventType;
    data?: EventData;
};
type EventSignal = Signal<typeof eventSignalType, EventPayload>;
declare const initSignalType: "init";
declare const stateChangeSignalType: "stateChange";
type StateChangeType = string;
type StateChangeSignalPayload = {
    state: StateChangeType;
    previousState?: StateChangeType;
};
type StateChangeSignal = Signal<typeof stateChangeSignalType, StateChangeSignalPayload>;
declare function createNamespacedBeacon(namespace: SignalNamespace): NamespacedBeacon;
declare function createErrorSignal(namespace: SignalNamespace, payload?: ErrorPayload): ErrorSignal;
declare function createEventSignal(namespace: SignalNamespace, payload?: EventPayload): EventSignal;
declare function createStateChangeSignal(namespace: SignalNamespace, payload?: StateChangeSignalPayload): StateChangeSignal;
declare function createErrorTriggerProps(namespace?: SignalNamespace, type?: string): Pick<Signal, "namespace"> & {
    type: ErrorSignal["type"];
} & {
    payload?: {
        type: string;
    };
};
declare function createEventTriggerProps(namespace?: SignalNamespace, type?: string): Pick<Signal, "namespace"> & {
    type: EventSignal["type"];
} & {
    payload?: {
        type: string;
    };
};
declare function createInitTriggerProps(namespace?: SignalNamespace): Pick<Signal, "type" | "namespace">;
declare function createStateChangeTriggerProps(namespace?: SignalNamespace, state?: string, previousState?: string): Pick<Signal, "type" | "namespace">;
declare function createTriggerPropsForAllSignals(namespace?: SignalNamespace): Pick<Signal, "type" | "namespace">;
declare function createTriggerForAllSignalTypes(): Pick<Signal, "type">;
declare function createTriggerForAllNamespaces(): Pick<Signal, "namespace">;
declare function convertSignalToTrigger(signal: Signal): SignalTriggerProps;
declare function filterSignals(list: Signal[], filterProps: Partial<Signal>): Signal[];
declare function isEventSignal(signal: Signal): boolean;
declare function isErrorSignal(signal: Signal): boolean;
declare function isInitSignal(signal: Signal): boolean;
declare function isStateChangeSignal(signal: Signal): boolean;
declare function isNamespacedSignal(signal: Signal, namespace: SignalNamespace): boolean;
declare function getEventSignalPayload(signal: Signal): EventPayload | null;
declare function getStateChangeSignalPayload(signal: Signal): StateChangeSignalPayload | null;
declare function getErrorSignalPayload(signal: Signal): ErrorPayload | null;
declare function waitForSignals(beacon: Beacon, triggers: (SignalType | Partial<Signal>)[], options?: {
    allowSkipping?: boolean;
    strictOrder?: boolean;
    rejectOn?: (SignalType | Partial<Signal>)[];
}): Promise<Omit<Signal, "context">[]>;
/**
 * Returns the session storage key for the user data.
 * @param settings
 * @returns string
 */
declare const getUserStoreKey: (settings: Partial<UserManagerSettings>) => string;
/**
 * Gets user data from storage
 * @param settings
 * @param storage
 * @returns
 */
declare const getUserFromStorage: (settings: Pick<UserManagerSettings, "authority" | "client_id">, sourceStorage?: Storage) => UserReturnType;
/**
 * Checks is the user expired. Reads the expired and expires_at properties of the User object
 * @param user
 * @returns
 */
declare const isUserExpired: (user?: Partial<User$0> | null) => boolean;
/**
 * Returns true, if user is not expired and has an access token
 * @param user
 * @returns
 */
declare const isValidUser: (user?: User$0 | null) => boolean;
/**
 *
 * @param user
 * @param tokenType
 * @returns
 */
declare const pickUserToken: (user: UserReturnType, tokenType: Parameters<OidcClient["getToken"]>[0]) => string;
declare function createOidcClient(props: OidcClientProps): OidcClient;
/**
 * Gets the api tokens from storage
 * @param storage
 * @returns
 */
declare const getApiTokensFromStorage: (sourceStorage?: Storage) => TokenData | null;
/**
 * Removes the api tokens from storage
 * @param storage
 */
declare const removeApiTokensFromStorage: (sourceStorage?: Storage) => void;
/**
 * Sets the api tokens to storage
 * @param tokenObj
 * @param storage
 */
declare const setApiTokensToStorage: (tokenObj: TokenData, sourceStorage?: Storage) => void;
/**
 * Gets one api token from storage
 * @param tokenKey
 * @param storage
 * @returns
 */
declare const getApiTokenFromStorage: (tokenKey: string, sourceStorage?: Storage) => string | undefined;
/**
 *  Removes the user reference from stored api tokens. Reference is the access token used when fetching api tokens
 * @param storage
 */
declare const removeUserReferenceFromStorage: (sourceStorage?: Storage) => void;
/**
 * Stores user reference to stored api tokens. Reference should be the access token used when fetching api tokens
 * @param reference
 * @param storage
 */
declare const setUserReferenceToStorage: (reference: string, sourceStorage?: Storage) => void;
/**
 * Returns the user reference to stored api tokens. Reference is the access token used when fetching api tokens
 * @param storage
 * @returns
 */
declare const getUserReferenceFromStorage: (sourceStorage?: Storage) => string | null;
declare function createApiTokenClient(props: ApiTokenClientProps): ApiTokenClient;
declare function createGraphQLModule<Q = GraphQLQueryResult, T = GraphQLCache>({ graphQLClient, query, queryOptions, options, queryHelper, useApolloClientModule }: GraphQLModuleModuleProps<T, Q>): GraphQLModule<T, Q>;
/**
 * IMPORTANT NOTICE:
 *
 * Apollo HttpLink converts all header keys to lower-case by default.
 * To bypass this, the user has to provide a HttpLink and not to use options.uri, because HttpLink created here
 * does not change the default behaviour.
 *
 * Example: new HttpLink({ uri, preserveHeaderCase: true }
 *
 */
declare function createApolloClientModule<T = InMemoryCache>(props: ApolloClientModuleProps<T>): ApolloClientModule<T>;
type ApiTokensClientErrorType = keyof typeof apiTokensClientError;
declare const apiTokensClientError: {
    readonly API_TOKEN_FETCH_FAILED: "API_TOKEN_FETCH_FAILED";
    readonly INVALID_API_TOKENS: "INVALID_API_TOKENS";
    readonly INVALID_USER_FOR_API_TOKENS: "INVALID_USER_FOR_API_TOKENS";
};
declare class ApiTokensClientError extends Error {
    message: string;
    type: ApiTokensClientErrorType;
    originalError?: Error | null;
    constructor(message: string, type: ApiTokensClientErrorType, originalError?: Error | null);
    get isFetchError(): boolean;
    get isInvalidTokensError(): boolean;
    get isInvalidApiTokensUserError(): boolean;
}
type SessionPollerErrorType = keyof typeof sessionPollerErrors;
declare const sessionPollerErrors: {
    readonly SESSION_ENDED: "SESSION_ENDED";
    readonly SESSION_POLLING_FAILED: "SESSION_POLLING_FAILED";
};
declare class SessionPollerError extends Error {
    message: string;
    type: SessionPollerErrorType;
    originalError?: Error | null;
    constructor(message: string, type: SessionPollerErrorType, originalError?: Error | null);
    get isSessionEnded(): boolean;
    get isSessionPollingFailure(): boolean;
}
declare function isHandlingLoginCallbackError(error: OidcClientError): boolean;
type PartialContext = Partial<QueryOptions["context"]>;
type QueryHeaders = Record<string, unknown>;
declare function mergeQueryOptionContexts(options: QueryOptions, overrideContext: PartialContext): QueryOptions;
declare function mergeHeadersToQueryOptions(options: QueryOptions, headers: QueryHeaders): QueryOptions;
declare function mergeAuthorizationHeaderToQueryOptions(options: QueryOptions, authHeader: string): QueryOptions;
declare function mergeQueryOptions(target: Partial<GraphQLModuleModuleProps["queryOptions"]>, overrides: Partial<GraphQLModuleModuleProps["queryOptions"]>): Partial<Omit<QueryOptions<import("@apollo/client").OperationVariables, GraphQLQueryResult>, "query">>;
declare function setBearerToQueryOptions(queryOptions: QueryOptions, token: string): QueryOptions<import("@apollo/client").OperationVariables, any>;
declare function appendFetchOptions(queryOptions: QueryOptions, newOptions: Partial<Parameters<typeof fetch>[1]>): QueryOptions<import("@apollo/client").OperationVariables, any>;
type LoginProviderProps = {
    userManagerSettings: OidcClientProps["userManagerSettings"];
    apiTokensClientSettings?: ApiTokenClientProps;
    sessionPollerSettings?: SessionPollerOptions;
    debug?: boolean;
    modules?: ConnectedModule[];
};
/**
 * For vanilla js usage. Creates and initialises beacon and modules
 * @param props Exclude<LoginProviderProps, 'children'>
 */
declare function createLoginSystem(props: Exclude<LoginProviderProps, "children">): Beacon;
type ApiTokensEventSignal = EventSignal & {
    payload: {
        type: ApiTokensClientEvent;
        data: TokenData | null;
    };
};
declare function createTriggerPropsForAllApiTokensClientSignals(): SignalTriggerProps;
declare const triggerForAllApiTokensClientSignals: SignalTrigger;
declare function isApiTokensClientSignal(signal: Signal): boolean;
declare function createApiTokensClientEventSignal({ type, data }: {
    type: ApiTokensClientEvent;
    data?: TokenData | null;
}): ApiTokensEventSignal;
// Makes no sense to check, if data (tokens) match, because actual values of the tokens are not important in signals.
// So adding "data" to an api tokens trigger is useless, so this function won't add it.
// data === null, can be checked manually if needed
declare function createApiTokensClientEventTriggerProps({ type }: {
    type: ApiTokensClientEvent;
}): Pick<ApiTokensEventSignal, "type" | "namespace"> & {
    payload: {
        type: ApiTokensClientEvent;
    };
};
declare const triggerForAllApiTokensClientEvents: SignalTrigger;
declare function getApiTokensClientEventPayload(signal: Signal): EventPayload | null;
declare function isApiTokensRemovedSignal(signal?: Signal): boolean;
declare function isApiTokensRenewalStartedSignal(signal?: Signal): boolean;
declare function isApiTokensUpdatedSignal(signal?: Signal): boolean;
declare const apiTokensRemovedTrigger: SignalTrigger;
declare const apiTokensRenewalStartedTrigger: SignalTrigger;
declare const apiTokensUpdatedTrigger: SignalTrigger;
/** error triggers */
declare function createApiTokensClientErrorSignal(error: ApiTokensClientError): ErrorSignal;
declare const triggerForAllApiTokensClientErrors: SignalTrigger;
declare function getApiTokensClientErrorPayload(signal: Signal): ApiTokensClientError | null;
declare function isApiTokensFetchFailedErrorSignal(signal: Signal): boolean;
declare function isInvalidApiTokensUserErrorSignal(signal: Signal): boolean;
declare function isInvalidApiTokensErrorSignal(signal: Signal): boolean;
declare const invalidApiTokensErrorTrigger: SignalTrigger;
declare const apiTokensFetchFailedErrorTrigger: SignalTrigger;
declare const invalidApiTokensUserErrorTrigger: SignalTrigger;
type OidcClientEventSignal = EventSignal & {
    payload: {
        type: OidcClientEvent;
        data?: User$0 | null;
    };
};
declare function createTriggerPropsForAllOidcClientSignals(): SignalTriggerProps;
// pre-defined triggers and triggerProps
declare const triggerForAllOidcClientSignals: SignalTrigger;
declare function isOidcClientSignal(signal: Signal): boolean;
/** State changes */
declare function createOidcClientStateChangeSignal(payload: StateChangeSignalPayload): StateChangeSignal;
declare function getOidcClientStateChangePayload(signal: Signal): StateChangeSignalPayload | null;
declare function isLoggingOutSignal(signal?: Signal): boolean;
declare function isLoggingInSignal(signal?: Signal): boolean;
declare function isHandlingLoginCallbackSignal(signal?: Signal): boolean;
declare function isNoSessionSignal(signal?: Signal): boolean;
declare function isValidSessionSignal(signal?: Signal): boolean;
declare function createTriggerPropsForAllOidcClientStateChanges(): SignalTriggerProps;
declare const triggerForAllOidcClientStateChanges: SignalTrigger;
declare const loggingOutTrigger: SignalTrigger;
declare const loggingInTrigger: SignalTrigger;
declare const handlingLoginCallbackTrigger: SignalTrigger;
declare const validSessionTrigger: SignalTrigger;
declare const noSessionTrigger: SignalTrigger;
/** Event signals */
declare function createOidcClientEventSignal(payload?: EventPayload): OidcClientEventSignal;
declare function createTriggerPropsForAllOidcClientEvents(): SignalTriggerProps;
declare const triggerForAllOidcClientEvents: SignalTrigger;
declare function getOidcClientEventPayload(signal: Signal): EventPayload | null;
declare function isUserRemovedSignal(signal?: Signal): boolean;
declare function isUserRenewalStartedSignal(signal?: Signal): boolean;
declare function isUserUpdatedSignal(signal?: Signal): boolean;
declare const userRemovedTrigger: SignalTrigger;
declare const userRenewalStartedTrigger: SignalTrigger;
declare const userUpdatedTrigger: SignalTrigger;
/** Error signals */
declare function createOidcClientErrorSignal(error: OidcClientError): ErrorSignal;
declare function createTriggerPropsForAllOidcClientErrors(): SignalTriggerProps;
declare const triggerForAllOidcClientErrors: SignalTrigger;
declare function getOidcClientErrorPayload(signal: Signal): ErrorPayload | null;
declare function isInvalidUserErrorSignal(signal: Signal): boolean;
declare function isRenewalErrorSignal(signal: Signal): boolean;
declare function isSigninErroSignal(signal: Signal): boolean;
declare const renewalErrorTrigger: SignalTrigger;
declare const invalidUserErrorTrigger: SignalTrigger;
declare const signInErrorTrigger: SignalTrigger;
type SessionPollerEventSignal = EventSignal & {
    payload: {
        type: SessionPollerEvent;
    };
};
declare function isSessionPollerSignal(signal: Signal): boolean;
declare function createTriggerPropsForAllSessionPollerSignals(): SignalTriggerProps;
// pre-defined triggers and triggerProps
declare const triggerForAllSessionPollerSignals: SignalTrigger;
/* event signals */
declare function getSessionPollerEventPayload(signal: Signal): EventPayload | null;
declare function createSessionPollerEventSignal(payload: EventPayload): SessionPollerEventSignal;
declare function isSessionPollerStartedSignal(signal?: Signal): boolean;
declare function isSessionPollerStoppedSignal(signal?: Signal): boolean;
// pre-defined triggers and triggerProps
declare function createTriggerPropsForAllSessionPollerEvents(): SignalTriggerProps;
declare const triggerForAllSessionPollerEvents: SignalTrigger;
declare const sessionPollingStoppedTrigger: SignalTrigger;
declare const sessionPollingStartedTrigger: SignalTrigger;
/* error signals */
declare function createTriggerPropsForAllSessionPollerErrors(): SignalTriggerProps;
declare function createSessionPollerErrorSignal(error: SessionPollerError): ErrorSignal;
declare function getSessionPollerErrorPayload(signal: Signal): ErrorPayload | null;
declare function isSessionEndedSignal(signal: Signal): boolean;
declare function isSessionPollingFailureSignal(signal: Signal): boolean;
// pre-defined triggers
declare const triggerForAllSessionPollerErrors: SignalTrigger;
declare const sessionEndedTrigger: SignalTrigger;
declare const sessionPollingFailedTrigger: SignalTrigger;
type GraphQLModuleEventSignal = EventSignal & {
    payload: {
        type: GraphQLModuleEvent;
        data: GraphQLQueryResult | null;
    };
};
declare function isGraphQLModuleSignal(signal: Signal): boolean;
declare function getGraphQLModuleEventPayload(signal: Signal): EventPayload | null;
declare function getGraphQLModuleErrorPayload(signal: Signal): GraphQLModuleError | null;
/**
 *  is...ErrorSignal checkers
 */
declare function isGraphQLModuleNoApiTokensErrorSignal(signal: Signal): boolean;
declare function isGraphQLModuleNoClientErrorSignal(signal: Signal): boolean;
declare function isGraphQLModuleLoadFailedSignal(signal: Signal): boolean;
/**
 * Signal creators
 */
declare function createGraphQLModuleEventSignal({ type, data }: Partial<GraphQLModuleEventSignal["payload"]>): GraphQLModuleEventSignal;
declare function createGraphQLModuleErrorSignal(error: GraphQLModuleError): ErrorSignal;
/**
 *  trigger creators
 */
declare function createTriggerPropsForAllGraphQLModuleSignals(): SignalTriggerProps;
/**
 * Triggers
 */
declare const triggerForAllGraphQLModuleSignals: SignalTrigger;
declare const triggerForAllGraphQLModuleEvents: SignalTrigger;
declare const triggerForAllGraphQLModuleErrors: SignalTrigger;
declare const loadFailedErrorTrigger: SignalTrigger;
declare const noApiTokensErrorTrigger: SignalTrigger;
declare const noClientErrorTrigger: SignalTrigger;
declare const graphQLModuleClearedTrigger: SignalTrigger;
declare const graphQLModuleLoadingTrigger: SignalTrigger;
declare const graphQLModuleLoadAbortedTrigger: SignalTrigger;
declare const graphQLModuleLoadSuccessTrigger: SignalTrigger;
declare function isGraphQLModuleClearedSignal(signal?: Signal): boolean;
declare function isGraphQLModuleLoadingSignal(signal?: Signal): boolean;
declare function isGraphQLModuleLoadAbortedSignal(signal?: Signal): boolean;
declare function isGraphQLModuleLoadSuccessSignal(signal?: Signal): boolean;
export { User$0 as User, Profile, ApiTokenClientProps, TokenData, ApiTokenClient, ApiTokensClientEvent, SessionPoller, SessionPollerEvent, SessionPollerOptions, GraphQLModule, GraphQLModuleModuleProps, GraphQLModuleEvent, ApolloClientModule, ApolloClientModuleProps, ApolloClientModuleEvent, OidcClient, OidcClientEvent, OidcClientProps, OidcClientState, LoginProps, LogoutProps, Amr, SignalType, SignalNamespace, SignalPayload, ConnectedModule, Beacon, SignalContext, Signal, SignalListener, SignalTriggerProps, SignalTrigger, SignalListenerSource, Disposer, NamespacedBeacon, ErrorPayload, ErrorSignal, EventType, EventData, EventPayload, EventSignal, StateChangeType, StateChangeSignalPayload, StateChangeSignal, getUserStoreKey, getUserFromStorage, isUserExpired, isValidUser, pickUserToken, createOidcClient, getApiTokensFromStorage, removeApiTokensFromStorage, setApiTokensToStorage, getApiTokenFromStorage, removeUserReferenceFromStorage, setUserReferenceToStorage, getUserReferenceFromStorage, createApiTokenClient, createSessionPoller, createGraphQLModule, createApolloClientModule, createBeacon, createSignalTrigger, ApiTokensClientErrorType, apiTokensClientError, ApiTokensClientError, OidcClientErrorType, oidcClientErrors, OidcClientError, SessionPollerErrorType, sessionPollerErrors, SessionPollerError, GraphQLModuleErrorType, graphQLModuleError, GraphQLModuleError, isHandlingLoginCallbackError, appendFetchOptions, setBearerToQueryOptions, mergeQueryOptions, mergeAuthorizationHeaderToQueryOptions, mergeHeadersToQueryOptions, mergeQueryOptionContexts, createApiTokenClientTracker, apiTokensClientEvents, oidcClientEvents, sessionPollerEvents, graphQLModuleEvents, apolloClientModuleEvents, oidcClientStates, createLoginSystem, apiTokensClientNamespace, oidcClientNamespace, sessionPollerNamespace, graphQLModuleNamespace, apolloClientModuleNamespace, ApiTokensEventSignal, createTriggerPropsForAllApiTokensClientSignals, triggerForAllApiTokensClientSignals, isApiTokensClientSignal, createApiTokensClientEventSignal, createApiTokensClientEventTriggerProps, triggerForAllApiTokensClientEvents, getApiTokensClientEventPayload, isApiTokensRemovedSignal, isApiTokensRenewalStartedSignal, isApiTokensUpdatedSignal, apiTokensRemovedTrigger, apiTokensRenewalStartedTrigger, apiTokensUpdatedTrigger, createApiTokensClientErrorSignal, triggerForAllApiTokensClientErrors, getApiTokensClientErrorPayload, isApiTokensFetchFailedErrorSignal, isInvalidApiTokensUserErrorSignal, isInvalidApiTokensErrorSignal, invalidApiTokensErrorTrigger, apiTokensFetchFailedErrorTrigger, invalidApiTokensUserErrorTrigger, OidcClientEventSignal, createTriggerPropsForAllOidcClientSignals, triggerForAllOidcClientSignals, isOidcClientSignal, createOidcClientStateChangeSignal, getOidcClientStateChangePayload, isLoggingOutSignal, isLoggingInSignal, isHandlingLoginCallbackSignal, isNoSessionSignal, isValidSessionSignal, createTriggerPropsForAllOidcClientStateChanges, triggerForAllOidcClientStateChanges, loggingOutTrigger, loggingInTrigger, handlingLoginCallbackTrigger, validSessionTrigger, noSessionTrigger, createOidcClientEventSignal, createTriggerPropsForAllOidcClientEvents, triggerForAllOidcClientEvents, getOidcClientEventPayload, isUserRemovedSignal, isUserRenewalStartedSignal, isUserUpdatedSignal, userRemovedTrigger, userRenewalStartedTrigger, userUpdatedTrigger, createOidcClientErrorSignal, createTriggerPropsForAllOidcClientErrors, triggerForAllOidcClientErrors, getOidcClientErrorPayload, isInvalidUserErrorSignal, isRenewalErrorSignal, isSigninErroSignal, renewalErrorTrigger, invalidUserErrorTrigger, signInErrorTrigger, SessionPollerEventSignal, isSessionPollerSignal, createTriggerPropsForAllSessionPollerSignals, triggerForAllSessionPollerSignals, getSessionPollerEventPayload, createSessionPollerEventSignal, isSessionPollerStartedSignal, isSessionPollerStoppedSignal, createTriggerPropsForAllSessionPollerEvents, triggerForAllSessionPollerEvents, sessionPollingStoppedTrigger, sessionPollingStartedTrigger, createTriggerPropsForAllSessionPollerErrors, createSessionPollerErrorSignal, getSessionPollerErrorPayload, isSessionEndedSignal, isSessionPollingFailureSignal, triggerForAllSessionPollerErrors, sessionEndedTrigger, sessionPollingFailedTrigger, GraphQLModuleEventSignal, isGraphQLModuleSignal, getGraphQLModuleEventPayload, getGraphQLModuleErrorPayload, isGraphQLModuleNoApiTokensErrorSignal, isGraphQLModuleNoClientErrorSignal, isGraphQLModuleLoadFailedSignal, createGraphQLModuleEventSignal, createGraphQLModuleErrorSignal, createTriggerPropsForAllGraphQLModuleSignals, triggerForAllGraphQLModuleSignals, triggerForAllGraphQLModuleEvents, triggerForAllGraphQLModuleErrors, loadFailedErrorTrigger, noApiTokensErrorTrigger, noClientErrorTrigger, graphQLModuleClearedTrigger, graphQLModuleLoadingTrigger, graphQLModuleLoadAbortedTrigger, graphQLModuleLoadSuccessTrigger, isGraphQLModuleClearedSignal, isGraphQLModuleLoadingSignal, isGraphQLModuleLoadAbortedSignal, isGraphQLModuleLoadSuccessSignal, initSignalType, errorSignalType, eventSignalType, stateChangeSignalType, createNamespacedBeacon, createErrorSignal, createEventSignal, createStateChangeTriggerProps, createTriggerPropsForAllSignals, createTriggerForAllSignalTypes, createTriggerForAllNamespaces, convertSignalToTrigger, filterSignals, isErrorSignal, isEventSignal, isInitSignal, isStateChangeSignal, isNamespacedSignal, getEventSignalPayload, getStateChangeSignalPayload, getErrorSignalPayload, createInitTriggerProps, createEventTriggerProps, createErrorTriggerProps, createStateChangeSignal, waitForSignals };
export * from '../react/src/components/cookieConsentCore/cookieConsentCore';
